@@ -41,8 +41,13 @@ class ConvertXmindToExcel:
         if os.path.isfile(xmind_path):
             # 如果传递单个xmind文件，则直接转换
             self.convert_single_file(xmind_path, excel_path, ignore_layer_number)
-        if os.path.isdir(xmind_path):
-            # 如果传递xmind文件夹的路径，则遍历文件夹中的xmind文件进行转换，放到指定的目录下面
+        # 如果传递xmind文件夹的路径，则遍历文件夹中的xmind文件进行转换，放到指定的目录下面 或者 汇合到同一个Excel文件中
+        elif os.path.isdir(xmind_path):
+            # 如果Excel_path是指定的文件，则进行汇总
+            if excel_path.endswith('.xlsx'):
+                self.convert_multiple_file(xmind_path, excel_path, ignore_layer_number)
+                return
+            # 否则放到指定的目录下面
             if not os.path.exists(excel_path):
                 os.makedirs(excel_path)
             xmind_dir = os.walk(xmind_path)
@@ -54,6 +59,21 @@ class ConvertXmindToExcel:
                                              os.path.join(excel_path, file_name.replace('.xmind', '.xlsx')),
                                              ignore_layer_number)
 
+    # 将多个xmind转换为单个excel文件
+    def convert_multiple_file(self, xmind_path, excel_file_path, ignore_layer_number):
+        xmind_dir = os.walk(xmind_path)
+        for path, dir_list, file_list in xmind_dir:
+            for file_name in file_list:
+                if not file_name.endswith('.xmind'):
+                    continue
+                self.ignore_layer_number = int(ignore_layer_number)
+                self.parseXmindToDict(os.path.join(path, file_name))
+                self.index = 0
+            df = pd.DataFrame(self.markdown_dict)
+            writer = pd.ExcelWriter(excel_file_path, engine='xlsxwriter')
+            df.to_excel(writer, sheet_name='case_data', index=False)
+            writer.save()
+
     # 将单个xmind转换为单个excel文件
     def convert_single_file(self, xmind_path, excel_path, ignore_layer_number):
         try:
